@@ -1,21 +1,22 @@
+from collections.abc import Sequence
 from functools import lru_cache
 import json
 import re
-from typing import Any, Dict, List, Optional, Sequence, Tuple
+from typing import Any, Optional
 
 from docutils import nodes
 from docutils.parsers.rst import directives
 from sphinx.application import Sphinx
 from sphinx.util import logging
-from sphinx.util.docutils import SphinxDirective, SphinxRole
+from sphinx.util.docutils import SphinxRole
 
 from . import compiled
 from ._compat import read_text
-from .shared import WARNING_TYPE
+from .shared import WARNING_TYPE, SdDirective
 
 logger = logging.getLogger(__name__)
 
-OCTICON_VERSION = "v16.1.1"
+OCTICON_VERSION = "v19.8.0"
 
 OCTICON_CSS = """\
 .octicon {
@@ -46,13 +47,13 @@ def setup_icons(app: Sphinx) -> None:
 
 
 @lru_cache(1)
-def get_octicon_data() -> Dict[str, Any]:
+def get_octicon_data() -> dict[str, Any]:
     """Load all octicon data."""
     content = read_text(compiled, "octicons.json")
     return json.loads(content)
 
 
-def list_octicons() -> List[str]:
+def list_octicons() -> list[str]:
     """List available octicon names."""
     return list(get_octicon_data().keys())
 
@@ -72,8 +73,8 @@ def get_octicon(
     """
     try:
         data = get_octicon_data()[name]
-    except KeyError:
-        raise KeyError(f"Unrecognised octicon: {name}")
+    except KeyError as exc:
+        raise KeyError(f"Unrecognised octicon: {name}") from exc
 
     match = HEIGHT_REGEX.match(height)
     if not match:
@@ -85,7 +86,7 @@ def get_octicon(
 
     original_height = 16
     if "16" not in data["heights"]:
-        original_height = int(list(data["heights"].keys())[0])
+        original_height = int(next(iter(data["heights"].keys())))
     elif "24" in data["heights"]:
         if height_unit == "px":
             if height_value >= 24:
@@ -120,7 +121,7 @@ class OcticonRole(SphinxRole):
     Additional classes can be added to the element after a semicolon.
     """
 
-    def run(self) -> Tuple[List[nodes.Node], List[nodes.system_message]]:
+    def run(self) -> tuple[list[nodes.Node], list[nodes.system_message]]:
         """Run the role."""
         values = self.text.split(";") if ";" in self.text else [self.text]
         icon = values[0]
@@ -141,7 +142,7 @@ class OcticonRole(SphinxRole):
         return [node], []
 
 
-class AllOcticons(SphinxDirective):
+class AllOcticons(SdDirective):
     """Directive to generate all octicon icons.
 
     Primarily for self documentation.
@@ -151,28 +152,36 @@ class AllOcticons(SphinxDirective):
         "class": directives.class_option,
     }
 
-    def run(self) -> List[nodes.Node]:
-        """Run the directive."""
+    def run_with_defaults(self) -> list[nodes.Node]:
         classes = self.options.get("class", [])
-        list_node = nodes.bullet_list()
-        for icon in list_octicons():
-            item_node = nodes.list_item()
-            item_node.extend(
-                (
-                    nodes.literal(icon, icon),
-                    nodes.Text(": "),
-                    nodes.raw(
-                        "",
-                        nodes.Text(get_octicon(icon, classes=classes)),
-                        format="html",
-                    ),
-                )
+        table = nodes.table()
+        group = nodes.tgroup(cols=2)
+        table += group
+        group.extend(
+            (
+                nodes.colspec(colwidth=1),
+                nodes.colspec(colwidth=1),
             )
-            list_node += item_node
-        return [list_node]
+        )
+        body = nodes.tbody()
+        group += body
+        for icon in list_octicons():
+            row = nodes.row()
+            body += row
+            cell = nodes.entry()
+            row += cell
+            cell += nodes.literal(icon, icon)
+            cell = nodes.entry()
+            row += cell
+            cell += nodes.raw(
+                "",
+                get_octicon(icon, classes=classes),
+                format="html",
+            )
+        return [table]
 
 
-class fontawesome(nodes.Element, nodes.General):
+class fontawesome(nodes.Element, nodes.General):  # noqa: N801
     """Node for rendering fontawesome icon."""
 
 
@@ -186,12 +195,12 @@ class FontawesomeRole(SphinxRole):
         super().__init__()
         self.style = style
 
-    def run(self) -> Tuple[List[nodes.Node], List[nodes.system_message]]:
+    def run(self) -> tuple[list[nodes.Node], list[nodes.system_message]]:
         """Run the role."""
         icon, classes = self.text.split(";", 1) if ";" in self.text else [self.text, ""]
         icon = icon.strip()
         node = fontawesome(
-            icon=icon, classes=[self.style, f"fa-{icon}"] + classes.split()
+            icon=icon, classes=[self.style, f"fa-{icon}", *classes.split()]
         )
         self.set_source_info(node)
         return [node], []
@@ -238,7 +247,7 @@ def visit_fontawesome_warning(self, node: nodes.Element) -> None:
 
 
 @lru_cache(1)
-def get_material_icon_data(style: str) -> Dict[str, Any]:
+def get_material_icon_data(style: str) -> dict[str, Any]:
     """Load all octicon data."""
     content = read_text(compiled, f"material_{style}.json")
     return json.loads(content)
@@ -257,8 +266,8 @@ def get_material_icon(
     """
     try:
         data = get_material_icon_data(style)[name]
-    except KeyError:
-        raise KeyError(f"Unrecognised material-{style} icon: {name}")
+    except KeyError as exc:
+        raise KeyError(f"Unrecognised material-{style} icon: {name}") from exc
 
     match = HEIGHT_REGEX.match(height)
     if not match:
@@ -270,7 +279,7 @@ def get_material_icon(
 
     original_height = 20
     if "20" not in data["heights"]:
-        original_height = int(list(data["heights"].keys())[0])
+        original_height = int(next(iter(data["heights"].keys())))
     elif "24" in data["heights"]:
         if height_unit == "px":
             if height_value >= 24:
@@ -309,7 +318,7 @@ class MaterialRole(SphinxRole):
         super().__init__()
         self.style = style
 
-    def run(self) -> Tuple[List[nodes.Node], List[nodes.system_message]]:
+    def run(self) -> tuple[list[nodes.Node], list[nodes.system_message]]:
         """Run the role."""
         values = self.text.split(";") if ";" in self.text else [self.text]
         icon = values[0]
